//#ifndef __CINT__
#include "RooGlobalFunc.h"
//#endif
#include "RooRealVar.h"
#include "RooArgList.h"
#include "RooFormulaVar.h"
#include "RooDataSet.h"
#include "RooGaussian.h"
#include "RooChebychev.h"
#include "RooExponential.h"
#include "RooBifurGauss.h"
#include "RooAddModel.h"
#include "RooProdPdf.h"
#include "TCanvas.h"
#include "RooPlot.h"
#include "RooHist.h"
#include "RooCBShape.h"
#include "RooPolynomial.h"
#include "RooBinning.h"
#include "RooDataHist.h"
#include "TH1.h"
#include "TH2.h"
#include "RooAddPdf.h"
#include "RooProdPdf.h"
#include "RooFitResult.h"
#include "RooGenericPdf.h"
#include "RooLandau.h"
#include "TChain.h"
#include "TCanvas.h"
#include "TAxis.h"
#include "RooPlot.h"
#include "RooCategory.h"
#include "RooSuperCategory.h"
#include "RooSimultaneous.h"
#include "RooNLLVar.h"
#include "TFile.h"
#include "myRooJohnsonSU.cpp"
//#include "myRooPolBG.cpp"

using namespace RooFit ;
using namespace std;

void kshort_mass()
{
  TFile * f = new TFile("KS_pipi_histo_b17_05_02_05_200bin.root");   
  //TH1 *h1 = new TH1F("h1","histogram",200, 0.45, 0.55);
  //h1 = (TH1*)f-> Get("Ks_7");

  TH1 *h1 = (TH1*)f-> Get("Ks_7");
  
  RooRealVar mpipi("d0pi_kpi","", 0.45, 0.45);
  RooDataHist data("data","data", RooArgList(mpipi),h1);
  
  //signal
  RooRealVar f_J("f_{J}", "",0.86, 0, 1);
  RooRealVar mu_J("#mu_{J}","mean_johnson",0.49,0.45,0.55 );                                                          
  RooRealVar sigma_J ("#sigma_{J}", "sigma_johnson",  0.01, 0, 0.5);                                                                        
  RooRealVar gamma_J("#gamma_{J}", "gamma", 1, -20., 20.);                                                                                 
  RooRealVar delta_J("#delta_{J}", "delta", 12, -20., 20.);
  myRooJohnsonSU johnson("johnson", "Johnson PDF", mpipi, mu_J, sigma_J, delta_J, gamma_J );                                                
  
  RooRealVar f_G1("f_{G}", "",0.9, 0, 1);
  RooRealVar mu_G1("#mu_{G1}", "mean_gauss1",0.49,0.45,0.55);        
  RooRealVar mu_G2("#mu_{G2}", "mean_gauss2",0.49,0.45,0.55);        
  RooRealVar sigma_G1("#sigma_{G1}", "sigma_gauss1", 0.01, 0, 0.16);                                                                       
  RooRealVar sigma_G2("#sigma_{G2}", "sigma_gauss2", 0.01, 0, 0.16);
  
  RooGaussian gauss1("gauss1", "1st gaussian PDF", mpipi, mu_G1, sigma_G1);                                                           
  RooGaussian gauss2("gauss2", "2nd gaussian PDF", mpipi, mu_G1, sigma_G2);                                                           
  RooAddPdf doublegaussian("doublegaussian", "double_gaussian", gauss1, gauss2, f_G1);                                                 
  RooAddPdf sig("sig", "signal_function", johnson, doublegaussian, f_J);                 
  
  //background
  RooRealVar a("a", "A", -9.275,-15.,0.);
  RooExponential bkg("bkg", "exponential", mpipi, a);
  
  //total
  RooRealVar n_sig("N_{sig}", "n_{s}", 200000, 0, 1e7);
  RooRealVar n_bkg("N_{bkg}", "n_{b}", 10000,0,1e7);
  RooAddPdf pdf("pdf", "two component model",RooArgList(sig, bkg), RooArgList(n_sig, n_bkg));

  //fit
  RooFitResult *fitresult = pdf.fitTo(data, Save(true), Strategy(2), Extended(true));
      
  RooPlot* mpipiplot = mpipi.frame();
  data.plotOn(mpipiplot);
  //sig.plotOn(d0piplot);
  //sig.paramOn(d0piplot);
  pdf.plotOn(mpipiplot);
  pdf.paramOn(mpipiplot);
  cout << "chi^2 = " << mpipiplot->chiSquare() << endl;

  RooHist* hpull = mpipiplot->pullHist();
  hpull->SetFillStyle(1001);
  hpull->SetFillColor(1);
  for(int i=0;i<hpull->GetN();++i) hpull->SetPointError(i,0.0,0.0,0.0,0.0);
  RooPlot* pullplot = mpipi.frame(Title(" "));
  pullplot->addPlotable(hpull,"B");
  //pullplot->SetYTitle("Pull");
  pullplot->SetXTitle("#it{m(#pi^{+}#pi^{-})} [GeV/c^{2}]");
  pullplot->SetMinimum(-4.);
  pullplot->SetMaximum(4.);
  pullplot->GetXaxis()->SetLabelSize(0.1);
  pullplot->GetXaxis()->SetTitleSize(0.1);
  pullplot->GetYaxis()->SetLabelSize(0.07);
  
  TCanvas *canvas = new TCanvas("canvas","canvas", 600, 600);

  Double_t xlow, ylow, xup, yup;
  canvas->GetPad(0)->GetPadPar(xlow,ylow,xup,yup);
  canvas->Divide(1,2);

  TVirtualPad *upPad = canvas->GetPad(1);
  upPad->SetPad(xlow,ylow+0.25*(yup-ylow),xup,yup);
  
  TVirtualPad *dwPad = canvas->GetPad(2);
  dwPad->SetPad(xlow,ylow,xup,ylow+0.25*(yup-ylow));

  canvas->Update();
  canvas->cd(1);
  
  pdf.plotOn(mpipiplot,Components(RooArgSet(sig)),LineColor(kRed),LineStyle(kDashed));

  mpipiplot->Draw();
  canvas->cd(2);
  pullplot->Draw();
  
  canvas->Update();
   
}

  



  
